==> qtjambi-qml-debuginfo-windows-x64-5.15.17.jar: sources/QtJambiQml/QQmlExpression_shell.h <==
#ifndef QQMLEXPRESSION_SHELL_H
#define QQMLEXPRESSION_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtQml/qqmlexpression.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmlerror.h>
#include <QtQml/qqmlscriptstring.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QQmlExpression_shell : public QQmlExpression, public QtJambiShellInterface
{
public:
    QQmlExpression_shell();
    QQmlExpression_shell(QQmlContext* arg__1, QObject* arg__2, const QString& arg__3, QObject* arg__4 = nullptr);
    QQmlExpression_shell(const QQmlScriptString& arg__1, QQmlContext* arg__2 = nullptr, QObject* arg__3 = nullptr, QObject* arg__4 = nullptr);
    ~QQmlExpression_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQmlExpression_access : public QQmlExpression
{
};

#endif // QQMLEXPRESSION_SHELL_H

==> qtjambi-qml-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiQml/QQmlExpression_shell.h <==
#ifndef QQMLEXPRESSION_SHELL_H
#define QQMLEXPRESSION_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtQml/qqmlexpression.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmlerror.h>
#include <QtQml/qqmlscriptstring.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QQmlExpression_shell : public QQmlExpression, public QtJambiShellInterface
{
public:
    QQmlExpression_shell();
    QQmlExpression_shell(QQmlContext* arg__1, QObject* arg__2, const QString& arg__3, QObject* arg__4 = nullptr);
    QQmlExpression_shell(const QQmlScriptString& arg__1, QQmlContext* arg__2 = nullptr, QObject* arg__3 = nullptr, QObject* arg__4 = nullptr);
    ~QQmlExpression_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQmlExpression_access : public QQmlExpression
{
};

#endif // QQMLEXPRESSION_SHELL_H
